pub struct SplittableBufferHandle { /* private fields */ }Expand description
A clonable handle referencing the underlying SplittableBufferInner.
Can be captured inside background sub-read callbacks and consumed via into_buffer(self)
once all child OwnedBuffers and other handles drop to recover the merged OwnedBuffer.
Implementations
Sourceimpl SplittableBufferHandle
impl SplittableBufferHandle
Sourcepub fn into_buffer(self) -> Option<OwnedBuffer>
pub fn into_buffer(self) -> Option<OwnedBuffer>
Consumes this handle and attempts to unwrap the underlying Arc<SplittableBufferInner>.
Returns Some(parent_buffer) if this handle and all child OwnedBuffers carved from
SplittableBuffer have been dropped (Arc::strong_count == 1). Otherwise returns None.