BufferImpl

Struct BufferImpl 

pub struct BufferImpl<'a, H: Borrow<A>, A: ?Sized + BufferAllocator> { /* private fields */ }

Implementations

Source

impl<'a, H: Borrow<A>, A: ?Sized + BufferAllocator> BufferImpl<'a, H, A>

pub fn as_ref(&self) -> BufferRef<'_>

Takes a read-only reference to this buffer.

pub fn subslice<R: SliceRange>(&self, range: R) -> BufferRef<'_>

Takes a read-only reference to this buffer over range (which must be within the size of the buffer).

pub fn as_mut(&mut self) -> MutableBufferRef<'_>

Takes a read-write reference to this buffer.

pub fn subslice_mut<R: SliceRange>(&mut self, range: R) -> MutableBufferRef<'_>

Takes a read-write reference to this buffer over range (which must be within the size of the buffer).

pub fn len(&self) -> usize

Returns the buffer’s capacity.

pub fn as_slice(&self) -> &[u8]

Returns a slice of the buffer’s contents.

pub fn as_mut_slice(&mut self) -> &mut [u8]

Returns a mutable slice of the buffer’s contents.

pub fn copy_to_slice(&self, dest: &mut [u8])

Copies the contents of this buffer into dest.

Panics

Panics if dest.len() != self.len().

pub fn copy_from_slice(&mut self, src: &[u8])

Copies the contents of src into this buffer.

Panics

Panics if src.len() != self.len().

pub fn fill(&mut self, val: u8)

Fills the buffer with val.

pub fn range(&self) -> Range<usize>

Returns the range in the underlying BufferSource that this buffer covers.

pub fn allocator(&self) -> &A

Returns a reference to the allocator.

pub fn to_vec(&self) -> Vec<u8>

Returns the buffer’s contents as a Vec.

pub fn append_to(&self, vec: &mut Vec<u8>)

Appends the buffer’s contents to vec.

pub fn as_ptr(&self) -> *const u8

Returns a raw pointer to the buffer’s contents.

pub fn as_mut_ptr(&mut self) -> *mut u8

Returns a mutable raw pointer to the buffer’s contents.

pub fn as_ptr_slice(&self) -> PtrByteSlice<'_>

Returns a read-only pointer slice over the buffer.

pub fn as_mut_ptr_slice(&mut self) -> MutPtrByteSlice<'_>

Returns a mutable pointer slice over the buffer.